';
$parameters = array('user' => $user);
diff --git a/htdocs/contrat/tpl/index.html b/htdocs/contrat/tpl/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/core/ajax/index.html b/htdocs/core/ajax/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/core/boxes/index.html b/htdocs/core/boxes/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/core/class/html.formadmin.class.php b/htdocs/core/class/html.formadmin.class.php
index 7f83b5f1bac..411b45e03a7 100644
--- a/htdocs/core/class/html.formadmin.class.php
+++ b/htdocs/core/class/html.formadmin.class.php
@@ -47,20 +47,20 @@ class FormAdmin
/**
* Return html select list with available languages (key='en_US', value='United States' for example)
*
- * @param string $selected Language pre-selected
- * @param string $htmlname Name of HTML select
- * @param int $showauto Show 'auto' choice
- * @param array $filter Array of keys to exclude in list (opposite of $onlykeys)
- * @param string $showempty '1'=Add empty value or 'string to show'
- * @param int $showwarning Show a warning if language is not complete
- * @param int $disabled Disable edit of select
- * @param string $morecss Add more css styles
- * @param int $showcode 1=Add language code into label at begining, 2=Add language code into label at end
- * @param int $forcecombo Force to use combo box (so no ajax beautify effect)
- * @param int $multiselect Make the combo a multiselect
- * @param array $onlykeys Array of language keys to restrict list with the following keys (opposite of $filter). Example array('fr', 'es', ...)
- * @param int $mainlangonly 1=Show only main languages ('fr_FR' no' fr_BE', 'es_ES' not 'es_MX', ...)
- * @return string Return HTML select string with list of languages
+ * @param string|array $selected Language pre-selected. Can be an array if $multiselect is 1.
+ * @param string $htmlname Name of HTML select
+ * @param int $showauto Show 'auto' choice
+ * @param array $filter Array of keys to exclude in list (opposite of $onlykeys)
+ * @param string $showempty '1'=Add empty value or 'string to show'
+ * @param int $showwarning Show a warning if language is not complete
+ * @param int $disabled Disable edit of select
+ * @param string $morecss Add more css styles
+ * @param int $showcode 1=Add language code into label at begining, 2=Add language code into label at end
+ * @param int $forcecombo Force to use combo box (so no ajax beautify effect)
+ * @param int $multiselect Make the combo a multiselect
+ * @param array $onlykeys Array of language keys to restrict list with the following keys (opposite of $filter). Example array('fr', 'es', ...)
+ * @param int $mainlangonly 1=Show only main languages ('fr_FR' no' fr_BE', 'es_ES' not 'es_MX', ...)
+ * @return string Return HTML select string with list of languages
*/
public function select_language($selected = '', $htmlname = 'lang_id', $showauto = 0, $filter = null, $showempty = '', $showwarning = 0, $disabled = 0, $morecss = '', $showcode = 0, $forcecombo = 0, $multiselect = 0, $onlykeys = null, $mainlangonly = 0)
{
@@ -129,7 +129,7 @@ class FormAdmin
}
$valuetoshow = picto_from_langcode($key, 'class="saturatemedium"').' '.$valuetoshow;
- if ((string) $selected == (string) $keytouse) {
+ if ((is_string($selected) && (string) $selected == (string) $keytouse) || (is_array($selected) && in_array($keytouse, $selected))) {
$out .= '';
} else {
$out .= '';
diff --git a/htdocs/core/class/index.html b/htdocs/core/class/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/core/data/index.html b/htdocs/core/data/index.html
deleted file mode 100644
index 8b137891791..00000000000
--- a/htdocs/core/data/index.html
+++ /dev/null
@@ -1 +0,0 @@
-
diff --git a/htdocs/core/lib/index.html b/htdocs/core/lib/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/core/lib/project.lib.php b/htdocs/core/lib/project.lib.php
index 4162dc4bd51..438408733dd 100644
--- a/htdocs/core/lib/project.lib.php
+++ b/htdocs/core/lib/project.lib.php
@@ -204,7 +204,7 @@ function project_prepare_head(Project $project)
$h++;
}
- if ($conf->eventorganization->enabled) {
+ if ($conf->eventorganization->enabled && !empty($project->usage_organize_event)) {
$langs->load('eventorganization');
$head[$h][0] = DOL_URL_ROOT . '/eventorganization/conferenceorbooth_list.php?projectid=' . $project->id;
$head[$h][1] = $langs->trans("ConferenceOrBoothTab");
diff --git a/htdocs/core/login/index.html b/htdocs/core/login/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/core/menus/index.html b/htdocs/core/menus/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/core/menus/standard/eldy.lib.php b/htdocs/core/menus/standard/eldy.lib.php
index 440a6e021bc..c6369cf6ce1 100644
--- a/htdocs/core/menus/standard/eldy.lib.php
+++ b/htdocs/core/menus/standard/eldy.lib.php
@@ -590,24 +590,29 @@ function print_start_menu_entry($idsel, $classname, $showmode)
*/
function print_text_menu_entry($text, $showmode, $url, $id, $idsel, $classname, $atarget)
{
- global $langs;
+ global $conf, $langs;
+ //$conf->global->THEME_TOPMENU_DISABLE_TEXT=1;
if ($showmode == 1) {
print '';
print '
';
-if (!empty($conf->global->MAIN_SEARCH_FORM_ON_HOME_AREAS)) { // This is useless due to the global search combo
- // Search ficheinter
- $var = false;
- print '
';
-
-if (!empty($conf->global->MAIN_SEARCH_FORM_ON_HOME_AREAS)) { // This is useless due to the global search combo
- print '
';
- print '';
- print '
';
- print '
';
- print '
'.$langs->trans("Search").'
';
- print '
';
- print $langs->trans("SupplierOrder").':
';
- print "
\n";
-}
-
-
/*
* Statistics
*/
diff --git a/htdocs/fourn/commande/tpl/index.html b/htdocs/fourn/commande/tpl/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/fourn/facture/index.html b/htdocs/fourn/facture/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/fourn/facture/tpl/index.html b/htdocs/fourn/facture/tpl/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/fourn/js/index.html b/htdocs/fourn/js/index.html
deleted file mode 100644
index 8b137891791..00000000000
--- a/htdocs/fourn/js/index.html
+++ /dev/null
@@ -1 +0,0 @@
-
diff --git a/htdocs/fourn/paiement/index.html b/htdocs/fourn/paiement/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/ftp/admin/index.html b/htdocs/ftp/admin/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/holiday/class/index.html b/htdocs/holiday/class/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/holiday/img/index.html b/htdocs/holiday/img/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/holiday/index.html b/htdocs/holiday/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/hrm/admin/index.html b/htdocs/hrm/admin/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/hrm/class/index.html b/htdocs/hrm/class/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/hrm/establishment/index.html b/htdocs/hrm/establishment/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/includes/adodbtime/index.html b/htdocs/includes/adodbtime/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/includes/index.html b/htdocs/includes/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/install/mssql/functions/index.html b/htdocs/install/mssql/functions/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/install/mssql/index.html b/htdocs/install/mssql/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/install/mysql/data/index.html b/htdocs/install/mysql/data/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/install/mysql/functions/index.html b/htdocs/install/mysql/functions/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/install/mysql/index.html b/htdocs/install/mysql/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/install/mysql/migration/13.0.0-14.0.0.sql b/htdocs/install/mysql/migration/13.0.0-14.0.0.sql
index f2ae6c7d173..ba36b27e885 100644
--- a/htdocs/install/mysql/migration/13.0.0-14.0.0.sql
+++ b/htdocs/install/mysql/migration/13.0.0-14.0.0.sql
@@ -325,7 +325,7 @@ CREATE TABLE llx_eventorganization_conferenceorboothattendee(
note_private text,
date_creation datetime NOT NULL,
tms timestamp,
- fk_user_creat integer NOT NULL,
+ fk_user_creat integer,
fk_user_modif integer,
last_main_doc varchar(255),
import_key varchar(14),
@@ -339,7 +339,6 @@ ALTER TABLE llx_eventorganization_conferenceorboothattendee ADD INDEX idx_evento
ALTER TABLE llx_eventorganization_conferenceorboothattendee ADD INDEX idx_eventorganization_conferenceorboothattendee_fk_actioncomm (fk_actioncomm);
ALTER TABLE llx_eventorganization_conferenceorboothattendee ADD CONSTRAINT fx_eventorganization_conferenceorboothattendee_fk_actioncomm FOREIGN KEY (fk_actioncomm) REFERENCES llx_actioncomm(id);
ALTER TABLE llx_eventorganization_conferenceorboothattendee ADD INDEX idx_eventorganization_conferenceorboothattendee_email (email);
-ALTER TABLE llx_eventorganization_conferenceorboothattendee ADD CONSTRAINT llx_eventorganization_conferenceorboothattendee_fk_user_creat FOREIGN KEY (fk_user_creat) REFERENCES llx_user(rowid);
ALTER TABLE llx_eventorganization_conferenceorboothattendee ADD INDEX idx_eventorganization_conferenceorboothattendee_status (status);
ALTER TABLE llx_eventorganization_conferenceorboothattendee ADD UNIQUE INDEX uk_eventorganization_conferenceorboothattendee(fk_soc, fk_actioncomm, email);
diff --git a/htdocs/install/mysql/migration/index.html b/htdocs/install/mysql/migration/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/install/mysql/tables/index.html b/htdocs/install/mysql/tables/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/install/mysql/tables/llx_eventorganization_conferenceorboothattendee.key.sql b/htdocs/install/mysql/tables/llx_eventorganization_conferenceorboothattendee.key.sql
index 2314221b41d..3b9cc52e68f 100644
--- a/htdocs/install/mysql/tables/llx_eventorganization_conferenceorboothattendee.key.sql
+++ b/htdocs/install/mysql/tables/llx_eventorganization_conferenceorboothattendee.key.sql
@@ -22,7 +22,6 @@ ALTER TABLE llx_eventorganization_conferenceorboothattendee ADD CONSTRAINT fx_ev
ALTER TABLE llx_eventorganization_conferenceorboothattendee ADD INDEX idx_eventorganization_conferenceorboothattendee_fk_actioncomm (fk_actioncomm);
ALTER TABLE llx_eventorganization_conferenceorboothattendee ADD CONSTRAINT fx_eventorganization_conferenceorboothattendee_fk_actioncomm FOREIGN KEY (fk_actioncomm) REFERENCES llx_actioncomm(id);
ALTER TABLE llx_eventorganization_conferenceorboothattendee ADD INDEX idx_eventorganization_conferenceorboothattendee_email (email);
-ALTER TABLE llx_eventorganization_conferenceorboothattendee ADD CONSTRAINT llx_eventorganization_conferenceorboothattendee_fk_user_creat FOREIGN KEY (fk_user_creat) REFERENCES llx_user(rowid);
ALTER TABLE llx_eventorganization_conferenceorboothattendee ADD INDEX idx_eventorganization_conferenceorboothattendee_status (status);
-- END MODULEBUILDER INDEXES
diff --git a/htdocs/install/mysql/tables/llx_eventorganization_conferenceorboothattendee.sql b/htdocs/install/mysql/tables/llx_eventorganization_conferenceorboothattendee.sql
index c6ff6dedf66..026295627d0 100644
--- a/htdocs/install/mysql/tables/llx_eventorganization_conferenceorboothattendee.sql
+++ b/htdocs/install/mysql/tables/llx_eventorganization_conferenceorboothattendee.sql
@@ -27,7 +27,7 @@ CREATE TABLE llx_eventorganization_conferenceorboothattendee(
note_private text,
date_creation datetime NOT NULL,
tms timestamp,
- fk_user_creat integer NOT NULL,
+ fk_user_creat integer,
fk_user_modif integer,
last_main_doc varchar(255),
import_key varchar(14),
diff --git a/htdocs/install/pgsql/functions/index.html b/htdocs/install/pgsql/functions/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/install/pgsql/index.html b/htdocs/install/pgsql/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/install/sqlite3/functions/index.html b/htdocs/install/sqlite3/functions/index.html
deleted file mode 100644
index 8b137891791..00000000000
--- a/htdocs/install/sqlite3/functions/index.html
+++ /dev/null
@@ -1 +0,0 @@
-
diff --git a/htdocs/install/sqlite3/index.html b/htdocs/install/sqlite3/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/intracommreport/admin/index.html b/htdocs/intracommreport/admin/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/intracommreport/class/index.html b/htdocs/intracommreport/class/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/intracommreport/index.html b/htdocs/intracommreport/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/langs/en_US/admin.lang b/htdocs/langs/en_US/admin.lang
index 0bc0261e373..d52bfb0a6ee 100644
--- a/htdocs/langs/en_US/admin.lang
+++ b/htdocs/langs/en_US/admin.lang
@@ -1751,6 +1751,7 @@ CREATE_NEW_VAT_WITHOUT_AUTO_PAYMENT=Keep the checkbox “Automatically create th
##### Agenda #####
AgendaSetup=Events and agenda module setup
PasswordTogetVCalExport=Key to authorize export link
+SecurityKey = Security Key
PastDelayVCalExport=Do not export event older than
AGENDA_USE_EVENT_TYPE=Use events types (managed in menu Setup -> Dictionaries -> Type of agenda events)
AGENDA_USE_EVENT_TYPE_DEFAULT=Automatically set this default value for type of event in event create form
diff --git a/htdocs/langs/en_US/eventorganization.lang b/htdocs/langs/en_US/eventorganization.lang
index c0ff5e8e281..03fb460d6b9 100644
--- a/htdocs/langs/en_US/eventorganization.lang
+++ b/htdocs/langs/en_US/eventorganization.lang
@@ -91,3 +91,10 @@ EvntOrgConfirmed = Confirmed
EvntOrgNotQualified = Not Qualified
EvntOrgDone = Done
EvntOrgCancelled = Cancelled
+#
+# Public page
+#
+MissingOrBadSecureKey = The security key is invalid or missing
+EvntOrgWelcomeMessage = This form allows you to register as a new participant to the conference
+EvntOrgStartDuration = This conference starts on
+EvntOrgEndDuration = and ends on
diff --git a/htdocs/loan/class/index.html b/htdocs/loan/class/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/loan/index.html b/htdocs/loan/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/loan/payment/index.html b/htdocs/loan/payment/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/mailmanspip/class/index.html b/htdocs/mailmanspip/class/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/mailmanspip/index.html b/htdocs/mailmanspip/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/margin/admin/index.html b/htdocs/margin/admin/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/margin/lib/index.html b/htdocs/margin/lib/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/margin/tabs/index.html b/htdocs/margin/tabs/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/modulebuilder/admin/index.html b/htdocs/modulebuilder/admin/index.html
deleted file mode 100644
index 8b137891791..00000000000
--- a/htdocs/modulebuilder/admin/index.html
+++ /dev/null
@@ -1 +0,0 @@
-
diff --git a/htdocs/modulebuilder/template/admin/index.html b/htdocs/modulebuilder/template/admin/index.html
deleted file mode 100644
index 8b137891791..00000000000
--- a/htdocs/modulebuilder/template/admin/index.html
+++ /dev/null
@@ -1 +0,0 @@
-
diff --git a/htdocs/modulebuilder/template/class/index.html b/htdocs/modulebuilder/template/class/index.html
deleted file mode 100644
index 8b137891791..00000000000
--- a/htdocs/modulebuilder/template/class/index.html
+++ /dev/null
@@ -1 +0,0 @@
-
diff --git a/htdocs/modulebuilder/template/index.html b/htdocs/modulebuilder/template/index.html
deleted file mode 100644
index 8b137891791..00000000000
--- a/htdocs/modulebuilder/template/index.html
+++ /dev/null
@@ -1 +0,0 @@
-
diff --git a/htdocs/modulebuilder/template/js/index.html b/htdocs/modulebuilder/template/js/index.html
deleted file mode 100644
index 8b137891791..00000000000
--- a/htdocs/modulebuilder/template/js/index.html
+++ /dev/null
@@ -1 +0,0 @@
-
diff --git a/htdocs/modulebuilder/template/lib/index.html b/htdocs/modulebuilder/template/lib/index.html
deleted file mode 100644
index 8b137891791..00000000000
--- a/htdocs/modulebuilder/template/lib/index.html
+++ /dev/null
@@ -1 +0,0 @@
-
diff --git a/htdocs/modulebuilder/template/sql/index.html b/htdocs/modulebuilder/template/sql/index.html
deleted file mode 100644
index 8b137891791..00000000000
--- a/htdocs/modulebuilder/template/sql/index.html
+++ /dev/null
@@ -1 +0,0 @@
-
diff --git a/htdocs/mrp/ajax/index.html b/htdocs/mrp/ajax/index.html
deleted file mode 100644
index 8b137891791..00000000000
--- a/htdocs/mrp/ajax/index.html
+++ /dev/null
@@ -1 +0,0 @@
-
diff --git a/htdocs/mrp/class/index.html b/htdocs/mrp/class/index.html
deleted file mode 100644
index 8b137891791..00000000000
--- a/htdocs/mrp/class/index.html
+++ /dev/null
@@ -1 +0,0 @@
-
diff --git a/htdocs/mrp/js/index.html b/htdocs/mrp/js/index.html
deleted file mode 100644
index 8b137891791..00000000000
--- a/htdocs/mrp/js/index.html
+++ /dev/null
@@ -1 +0,0 @@
-
diff --git a/htdocs/mrp/tpl/index.html b/htdocs/mrp/tpl/index.html
deleted file mode 100644
index 8b137891791..00000000000
--- a/htdocs/mrp/tpl/index.html
+++ /dev/null
@@ -1 +0,0 @@
-
diff --git a/htdocs/opensurvey/class/index.html b/htdocs/opensurvey/class/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/opensurvey/css/index.html b/htdocs/opensurvey/css/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/opensurvey/img/index.html b/htdocs/opensurvey/img/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/paybox/admin/index.html b/htdocs/paybox/admin/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/paybox/img/index.html b/htdocs/paybox/img/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/paybox/index.html b/htdocs/paybox/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/paybox/lib/index.html b/htdocs/paybox/lib/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/paypal/admin/index.html b/htdocs/paypal/admin/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/paypal/img/index.html b/htdocs/paypal/img/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/paypal/index.html b/htdocs/paypal/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/paypal/lib/index.html b/htdocs/paypal/lib/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/printing/admin/index.html b/htdocs/printing/admin/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/printing/lib/index.html b/htdocs/printing/lib/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/product/admin/index.html b/htdocs/product/admin/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/product/ajax/index.html b/htdocs/product/ajax/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/product/canvas/index.html b/htdocs/product/canvas/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/product/canvas/product/index.html b/htdocs/product/canvas/product/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/product/canvas/product/tpl/index.html b/htdocs/product/canvas/product/tpl/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/product/canvas/service/index.html b/htdocs/product/canvas/service/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/product/canvas/service/tpl/index.html b/htdocs/product/canvas/service/tpl/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/product/class/index.html b/htdocs/product/class/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/product/composition/index.html b/htdocs/product/composition/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/product/dynamic_price/class/index.html b/htdocs/product/dynamic_price/class/index.html
deleted file mode 100644
index 8b137891791..00000000000
--- a/htdocs/product/dynamic_price/class/index.html
+++ /dev/null
@@ -1 +0,0 @@
-
diff --git a/htdocs/product/dynamic_price/index.html b/htdocs/product/dynamic_price/index.html
deleted file mode 100644
index 8b137891791..00000000000
--- a/htdocs/product/dynamic_price/index.html
+++ /dev/null
@@ -1 +0,0 @@
-
diff --git a/htdocs/product/index.php b/htdocs/product/index.php
index 7d5f59c1ed9..e2cb4799965 100644
--- a/htdocs/product/index.php
+++ b/htdocs/product/index.php
@@ -88,7 +88,8 @@ print load_fiche_titre($transAreaType, $linkback, 'product');
print '
';
-if (!empty($conf->global->MAIN_SEARCH_FORM_ON_HOME_AREAS)) { // This is useless due to the global search combo
+if (!empty($conf->global->MAIN_SEARCH_FORM_ON_HOME_AREAS)) { // This may be
+ is useless due to the global search combo
// Search contract
if ((!empty($conf->product->enabled) || !empty($conf->service->enabled)) && ($user->rights->produit->lire || $user->rights->service->lire)) {
$listofsearchfields['search_product'] = array('text'=>'ProductOrService');
diff --git a/htdocs/product/stats/index.html b/htdocs/product/stats/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/product/stock/class/index.html b/htdocs/product/stock/class/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/product/stock/img/index.html b/htdocs/product/stock/img/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/product/stock/index.php b/htdocs/product/stock/index.php
index ff2c99c0b09..b64068df48b 100644
--- a/htdocs/product/stock/index.php
+++ b/htdocs/product/stock/index.php
@@ -60,7 +60,7 @@ print load_fiche_titre($langs->trans("StocksArea"), '', 'stock');
print '
';
-if (!empty($conf->global->MAIN_SEARCH_FORM_ON_HOME_AREAS)) { // This is useless due to the global search combo
+if (!empty($conf->global->MAIN_SEARCH_FORM_ON_HOME_AREAS)) { // This may be useless due to the global search combo
print '
';
+/* Show list of project today */
-if (!empty($conf->global->MAIN_SEARCH_FORM_ON_HOME_AREAS)) { // This is useless due to the global search combo
- // Search project
- if (!empty($conf->projet->enabled) && $user->rights->projet->lire) {
- $listofsearchfields['search_task'] = array('text'=>'Task');
- }
-
- if (count($listofsearchfields)) {
- print '
';
-
-if (!empty($conf->global->MAIN_SEARCH_FORM_ON_HOME_AREAS)) { // This is useless due to the global search combo
- // Search project
- if (!empty($conf->projet->enabled) && $user->rights->projet->lire) {
- $listofsearchfields['search_project'] = array('text'=>'Project');
- }
-
- if (count($listofsearchfields)) {
- print '
';
- print ' ';
- }
-}
-
-
/*
* Statistics
*/
diff --git a/htdocs/public/eventorganization/attendee_subscription.php b/htdocs/public/eventorganization/attendee_subscription.php
new file mode 100644
index 00000000000..800c6dc469d
--- /dev/null
+++ b/htdocs/public/eventorganization/attendee_subscription.php
@@ -0,0 +1,398 @@
+
+ * Copyright (C) 2001-2002 Jean-Louis Bergamo
+ * Copyright (C) 2006-2013 Laurent Destailleur
+ * Copyright (C) 2012 Regis Houssin
+ * Copyright (C) 2012 J. Fernando Lagrange
+ * Copyright (C) 2018-2019 Frédéric France
+ * Copyright (C) 2018 Alexandre Spangaro
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 3 of the License, or
+ * (at your option) any later version.
+ *
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program. If not, see .
+ */
+
+/**
+ * \file htdocs/public/members/new.php
+ * \ingroup member
+ * \brief Example of form to add a new member
+ *
+ * Note that you can add following constant to change behaviour of page
+ * MEMBER_NEWFORM_AMOUNT Default amount for auto-subscribe form
+ * MEMBER_NEWFORM_EDITAMOUNT 0 or 1 = Amount can be edited
+ * MEMBER_NEWFORM_PAYONLINE Suggest payment with paypal, paybox or stripe
+ * MEMBER_NEWFORM_DOLIBARRTURNOVER Show field turnover (specific for dolibarr foundation)
+ * MEMBER_URL_REDIRECT_SUBSCRIPTION Url to redirect once subscribe submitted
+ * MEMBER_NEWFORM_FORCETYPE Force type of member
+ * MEMBER_NEWFORM_FORCEMORPHY Force nature of member (mor/phy)
+ * MEMBER_NEWFORM_FORCECOUNTRYCODE Force country
+ */
+
+if (!defined('NOLOGIN')) {
+ define("NOLOGIN", 1); // This means this output page does not require to be logged.
+}
+if (!defined('NOCSRFCHECK')) {
+ define("NOCSRFCHECK", 1); // We accept to go on this page from external web site.
+}
+if (!defined('NOIPCHECK')) {
+ define('NOIPCHECK', '1'); // Do not check IP defined into conf $dolibarr_main_restrict_ip
+}
+if (!defined('NOBROWSERNOTIF')) {
+ define('NOBROWSERNOTIF', '1');
+}
+if (!defined('NOIPCHECK')) {
+ define('NOIPCHECK', '1'); // Do not check IP defined into conf $dolibarr_main_restrict_ip
+}
+
+// For MultiCompany module.
+// Do not use GETPOST here, function is not defined and define must be done before including main.inc.php
+// TODO This should be useless. Because entity must be retrieve from object ref and not from url.
+$entity = (!empty($_GET['entity']) ? (int) $_GET['entity'] : (!empty($_POST['entity']) ? (int) $_POST['entity'] : 1));
+if (is_numeric($entity)) {
+ define("DOLENTITY", $entity);
+}
+
+require '../../main.inc.php';
+require_once DOL_DOCUMENT_ROOT.'/core/lib/company.lib.php';
+require_once DOL_DOCUMENT_ROOT.'/core/class/extrafields.class.php';
+require_once DOL_DOCUMENT_ROOT.'/eventorganization/class/conferenceorbooth.class.php';
+require_once DOL_DOCUMENT_ROOT.'/eventorganization/class/conferenceorboothattendee.class.php';
+require_once DOL_DOCUMENT_ROOT.'/core/class/html.formcompany.class.php';
+
+// Init vars
+$errmsg = '';
+$num = 0;
+$error = 0;
+$backtopage = GETPOST('backtopage', 'alpha');
+$action = GETPOST('action', 'aZ09');
+
+$key = 'DV3PH';
+$id = dol_decode(GETPOST('id'), $key);
+
+// Securekey check
+$securekey = GETPOST('securekey', 'alpha');
+if ($securekey != $conf->global->EVENTORGANIZATION_SECUREKEY) {
+ print $langs->trans('MissingOrBadSecureKey');
+ exit;
+}
+
+// Load translation files
+$langs->loadLangs(array("main", "companies", "install", "other", "eventorganization"));
+
+// Initialize technical object to manage hooks of page. Note that conf->hooks_modules contains array of hook context
+$hookmanager->initHooks(array('publicnewmembercard', 'globalcard'));
+
+$extrafields = new ExtraFields($db);
+
+$user->loadDefaultValues();
+
+
+/**
+ * Show header for new member
+ *
+ * @param string $title Title
+ * @param string $head Head array
+ * @param int $disablejs More content into html header
+ * @param int $disablehead More content into html header
+ * @param array $arrayofjs Array of complementary js files
+ * @param array $arrayofcss Array of complementary css files
+ * @return void
+ */
+function llxHeaderVierge($title, $head = "", $disablejs = 0, $disablehead = 0, $arrayofjs = '', $arrayofcss = '')
+{
+ global $user, $conf, $langs, $mysoc;
+
+ top_htmlhead($head, $title, $disablejs, $disablehead, $arrayofjs, $arrayofcss); // Show html headers
+
+ print '';
+
+ // Define urllogo
+ $urllogo = DOL_URL_ROOT.'/theme/common/login_logo.png';
+
+ if (!empty($mysoc->logo_small) && is_readable($conf->mycompany->dir_output.'/logos/thumbs/'.$mysoc->logo_small)) {
+ $urllogo = DOL_URL_ROOT.'/viewimage.php?cache=1&modulepart=mycompany&file='.urlencode('logos/thumbs/'.$mysoc->logo_small);
+ } elseif (!empty($mysoc->logo) && is_readable($conf->mycompany->dir_output.'/logos/'.$mysoc->logo)) {
+ $urllogo = DOL_URL_ROOT.'/viewimage.php?cache=1&modulepart=mycompany&file='.urlencode('logos/'.$mysoc->logo);
+ } elseif (is_readable(DOL_DOCUMENT_ROOT.'/theme/dolibarr_logo.svg')) {
+ $urllogo = DOL_URL_ROOT.'/theme/dolibarr_logo.svg';
+ }
+
+ print '
';
+ // Output html code for logo
+ if ($urllogo) {
+ print '
';
+ print '
';
+ print '';
+ print '
';
+ if (empty($conf->global->MAIN_HIDE_POWERED_BY)) {
+ print '
diff --git a/htdocs/core/db/index.html b/htdocs/core/db/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/core/filemanagerdol/browser/default/images/icons/32/index.html b/htdocs/core/filemanagerdol/browser/default/images/icons/32/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/core/filemanagerdol/browser/default/images/icons/index.html b/htdocs/core/filemanagerdol/browser/default/images/icons/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/core/filemanagerdol/browser/default/images/index.html b/htdocs/core/filemanagerdol/browser/default/images/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/core/filemanagerdol/browser/default/index.html b/htdocs/core/filemanagerdol/browser/default/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/core/filemanagerdol/browser/default/js/index.html b/htdocs/core/filemanagerdol/browser/default/js/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/core/filemanagerdol/browser/index.html b/htdocs/core/filemanagerdol/browser/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/core/filemanagerdol/connectors/index.html b/htdocs/core/filemanagerdol/connectors/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/core/filemanagerdol/connectors/php/index.html b/htdocs/core/filemanagerdol/connectors/php/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/core/filemanagerdol/index.html b/htdocs/core/filemanagerdol/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/core/index.html b/htdocs/core/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/core/js/index.html b/htdocs/core/js/index.html
deleted file mode 100644
index e69de29bb2d..00000000000
diff --git a/htdocs/core/lib/geturl.lib.php b/htdocs/core/lib/geturl.lib.php
index 435f02f1da0..531e366de77 100644
--- a/htdocs/core/lib/geturl.lib.php
+++ b/htdocs/core/lib/geturl.lib.php
@@ -152,20 +152,31 @@ function getURLContent($url, $postorget = 'GET', $param = '', $followlocation =
$hosttocheck = $newUrlArray['host'];
$hosttocheck = str_replace(array('[', ']'), '', $hosttocheck); // Remove brackets of IPv6
+ // Deny some reserved host names
+ if (in_array($hosttocheck, array('metadata.google.internal'))) {
+ $info['http_code'] = 400;
+ $info['content'] = 'Error bad hostname (Used by Google metadata). This value for hostname is not allowed.';
+ break;
+ }
+
+ // Clean host name $hosttocheck to convert it into an IP $iptocheck
if (in_array($hosttocheck, array('localhost', 'localhost.domain'))) {
$iptocheck = '127.0.0.1';
+ } elseif (in_array($hosttocheck, array('ip6-localhost', 'ip6-loopback'))) {
+ $iptocheck = '::1';
} else {
// TODO Resolve $iptocheck to get an IP and set CURLOPT_CONNECT_TO to use this ip
$iptocheck = $hosttocheck;
}
if (!filter_var($iptocheck, FILTER_VALIDATE_IP, FILTER_FLAG_IPV4 | FILTER_FLAG_IPV6)) { // This is not an IP
- $iptocheck = 0; //
+ $iptocheck = '0'; //
}
if ($iptocheck) {
if ($localurl == 0) { // Only external url allowed (dangerous, may allow to get malware)
if (!filter_var($iptocheck, FILTER_VALIDATE_IP, FILTER_FLAG_NO_PRIV_RANGE | FILTER_FLAG_NO_RES_RANGE)) {
+ // Deny ips like 10.0.0.0/8, 172.16.0.0/12, 192.168.0.0/16, 0.0.0.0/8, 169.254.0.0/16, 127.0.0.0/8 et 240.0.0.0/4, ::1/128, ::/128, ::ffff:0:0/96, fe80::/10...
$info['http_code'] = 400;
$info['content'] = 'Error bad hostname IP (private or reserved range). Must be an external URL.';
break;
@@ -152,20 +152,31 @@ function getURLContent($url, $postorget = 'GET', $param = '', $followlocation =
} else {
- // TODO Resolve $iptocheck to get an IP and set CURLOPT_CONNECT_TO to use this ip
+ // TODO Resolve $hosttocheck to get the IP $iptocheck and set CURLOPT_CONNECT_TO to use this ip
$iptocheck = $hosttocheck;
}